@@ -1,4 +1,3 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /* nautilus-view.h
  *
  * Copyright (C) 1999, 2000  Free Software Foundaton
@@ -29,9 +28,9 @@
 #include <gtk/gtk.h>
 #include <gio/gio.h>
 
-#include <libnautilus-private/nautilus-directory.h>
-#include <libnautilus-private/nautilus-file.h>
-#include <libnautilus-private/nautilus-link.h>
+#include "nautilus-directory.h"
+#include "nautilus-file.h"
+#include "nautilus-link.h"
 
 typedef struct NautilusFilesView NautilusFilesView;
 typedef struct NautilusFilesViewClass NautilusFilesViewClass;
@@ -175,17 +174,15 @@ struct NautilusFilesViewClass {
 
         void     (* invert_selection)        (NautilusFilesView *view);
 
-        /* Return an array of locations of selected icons in their view. */
-        GArray * (* get_selected_icon_locations) (NautilusFilesView *view);
-
         /* bump_zoom_level is a function pointer that subclasses must override
          * to change the zoom level of an object. */
         void    (* bump_zoom_level)          (NautilusFilesView *view,
                                               int                zoom_increment);
 
-        /* restore_default_zoom_level is a function pointer that subclasses must override
-         * to restore the zoom level of an object to a default setting. */
-        void    (* restore_default_zoom_level) (NautilusFilesView *view);
+        /*
+         * restore_default_zoom_level: restores the zoom level to 100% (or to
+         * whatever is considered the 'standard' zoom level for the view). */
+        void    (* restore_standard_zoom_level) (NautilusFilesView *view);
 
         /* can_zoom_in is a function pointer that subclasses must override to
          * return whether the view is at maximum size (furthest-in zoom level) */
@@ -195,6 +192,9 @@ struct NautilusFilesViewClass {
          * return whether the view is at minimum size (furthest-out zoom level) */
         gboolean (* can_zoom_out)            (NautilusFilesView *view);
 
+        /* The current zoom level as a percentage of the default (0, 1] */
+        gfloat   (* get_zoom_level_percentage) (NautilusFilesView *view);
+
         /* reveal_selection is a function pointer that subclasses may
          * override to make sure the selected items are sufficiently
          * apparent to the user (e.g., scrolled into view). By default,
@@ -202,13 +202,6 @@ struct NautilusFilesViewClass {
          */
         void     (* reveal_selection)        (NautilusFilesView *view);
 
-        /* merge_menus is a function pointer that subclasses can override to
-         * add their own menu items to the window's menu bar.
-         * If overridden, subclasses must call parent class's function.
-         */
-        void    (* merge_menus)              (NautilusFilesView *view);
-        void    (* unmerge_menus)            (NautilusFilesView *view);
-
         /* update_menus is a function pointer that subclasses can override to
          * update the sensitivity or wording of menu items in the menu bar.
          * It is called (at least) whenever the selection changes. If overridden,
@@ -233,22 +226,11 @@ struct NautilusFilesViewClass {
          * view's lifecycle. */
         gboolean (* using_manual_layout)     (NautilusFilesView *view);
 
-        /* is_read_only is a function pointer that subclasses may
-         * override to control whether or not the user is allowed to
-         * change the contents of the currently viewed directory. The
-         * default implementation checks the permissions of the
-         * directory.
-         */
-        gboolean (* is_read_only)            (NautilusFilesView *view);
-
         /* is_empty is a function pointer that subclasses must
          * override to report whether the view contains any items.
          */
         gboolean (* is_empty)                (NautilusFilesView *view);
 
-        gboolean (* can_rename_file)         (NautilusFilesView *view,
-                                              NautilusFile      *file);
-
         /* convert *point from widget's coordinate system to a coordinate
          * system used for specifying file operation positions, which is view-specific.
          *
@@ -277,9 +259,13 @@ struct NautilusFilesViewClass {
 
         NautilusWindow * (*get_window)       (NautilusFilesView *view);
 
-        GdkRectangle * (*compute_rename_popover_relative_to) (NautilusFilesView *view);
+        GdkRectangle * (* compute_rename_popover_pointing_to) (NautilusFilesView *view);
 
         GIcon *        (* get_icon)          (NautilusFilesView *view);
+
+        /* Use this to show an optional visual feedback when the directory is empty.
+         * By default it shows a widget overlay on top of the view */
+        void           (* check_empty_states)          (NautilusFilesView *view);
 };
 
 /* GObject support */
@@ -370,7 +356,6 @@ void              nautilus_files_view_bump_zoom_level            (NautilusFilesV
                                                                   int                     zoom_increment);
 void              nautilus_files_view_zoom_to_level              (NautilusFilesView      *view,
                                                                   gint                    level);
-void              nautilus_files_view_restore_default_zoom_level (NautilusFilesView      *view);
 gboolean          nautilus_files_view_can_zoom_in                (NautilusFilesView      *view);
 gboolean          nautilus_files_view_can_zoom_out               (NautilusFilesView      *view);
 void              nautilus_files_view_update_menus               (NautilusFilesView      *view);
